Struct signal_future::SignalFuture
source · pub struct SignalFuture { /* private fields */ }Expand description
A simple future that can be programmatically resolved externally using the controller that is provided in tandem when creating a SignalFuture. This makes it useful as a way to signal to some consumer of the future that something has completed, using standard async syntax and semantics.
Examples
struct DelayedWriter { fd: File, pending: Mutex<Vec<(u64, Vec<u8>, SignalFutureController)>> }
impl DelayedWriter {
pub async fn write(&self, offset: u64, data: Vec<u8>) {
let (fut, fut_ctl) = SignalFuture::new();
self.pending.lock().await.push((offset, data, fut_ctl));
fut.await
}
pub async fn background_loop(&self) {
loop {
sleep(Duration::from_millis(500));
for (offset, data, fut_ctl) in self.pending.lock().await.drain(..) {
self.fd.write_at(offset, data).await;
fut_ctl.signal();
};
};
}
}Implementations
sourceimpl SignalFuture
impl SignalFuture
pub fn new() -> (SignalFuture, SignalFutureController)